diff --git a/.gradle/7.3/checksums/checksums.lock b/.gradle/7.3/checksums/checksums.lock
index c0b49f4..ae20eda 100644
Binary files a/.gradle/7.3/checksums/checksums.lock and b/.gradle/7.3/checksums/checksums.lock differ
diff --git a/.gradle/7.3/checksums/md5-checksums.bin b/.gradle/7.3/checksums/md5-checksums.bin
index cf1bcff..6819251 100644
Binary files a/.gradle/7.3/checksums/md5-checksums.bin and b/.gradle/7.3/checksums/md5-checksums.bin differ
diff --git a/.gradle/7.3/checksums/sha1-checksums.bin b/.gradle/7.3/checksums/sha1-checksums.bin
index 851111b..9f7a473 100644
Binary files a/.gradle/7.3/checksums/sha1-checksums.bin and b/.gradle/7.3/checksums/sha1-checksums.bin differ
diff --git a/.gradle/7.3/executionHistory/executionHistory.bin b/.gradle/7.3/executionHistory/executionHistory.bin
index 21e1b1d..f4ec3cc 100644
Binary files a/.gradle/7.3/executionHistory/executionHistory.bin and b/.gradle/7.3/executionHistory/executionHistory.bin differ
diff --git a/.gradle/7.3/executionHistory/executionHistory.lock b/.gradle/7.3/executionHistory/executionHistory.lock
index d08223d..572a783 100644
Binary files a/.gradle/7.3/executionHistory/executionHistory.lock and b/.gradle/7.3/executionHistory/executionHistory.lock differ
diff --git a/.gradle/7.3/fileHashes/fileHashes.bin b/.gradle/7.3/fileHashes/fileHashes.bin
index b809d36..758d5a8 100644
Binary files a/.gradle/7.3/fileHashes/fileHashes.bin and b/.gradle/7.3/fileHashes/fileHashes.bin differ
diff --git a/.gradle/7.3/fileHashes/fileHashes.lock b/.gradle/7.3/fileHashes/fileHashes.lock
index 4c3c693..fdabc95 100644
Binary files a/.gradle/7.3/fileHashes/fileHashes.lock and b/.gradle/7.3/fileHashes/fileHashes.lock differ
diff --git a/.gradle/buildOutputCleanup/buildOutputCleanup.lock b/.gradle/buildOutputCleanup/buildOutputCleanup.lock
index ae1f22f..d44f7df 100644
Binary files a/.gradle/buildOutputCleanup/buildOutputCleanup.lock and b/.gradle/buildOutputCleanup/buildOutputCleanup.lock differ
diff --git a/.gradle/buildOutputCleanup/outputFiles.bin b/.gradle/buildOutputCleanup/outputFiles.bin
index 129b103..3b0f606 100644
Binary files a/.gradle/buildOutputCleanup/outputFiles.bin and b/.gradle/buildOutputCleanup/outputFiles.bin differ
diff --git a/.gradle/file-system.probe b/.gradle/file-system.probe
index 4efd0c8..7492e7c 100644
Binary files a/.gradle/file-system.probe and b/.gradle/file-system.probe differ
diff --git a/build.gradle b/build.gradle
index abf5c1b..743fae6 100644
--- a/build.gradle
+++ b/build.gradle
@@ -7,27 +7,27 @@ buildscript {
jcenter()
}
dependencies {
- classpath 'org.jooq:jooq-codegen:3.16.4'
- classpath 'org.postgresql:postgresql:42.3.2'
+ classpath 'org.jooq:jooq-codegen:latest.release'
+ classpath 'org.postgresql:postgresql:latest.release'
classpath 'org.jfrog.buildinfo:build-info-extractor-gradle:latest.release'
- classpath 'nu.studer.jooq:nu.studer.jooq.gradle.plugin:7.1.1'
+ classpath 'nu.studer.jooq:nu.studer.jooq.gradle.plugin:latest.release'
}
}
plugins {
- id 'nu.studer.jooq' version '7.1.1'
+ id 'nu.studer.jooq' version '8.2.1'
}
apply plugin: 'java'
apply plugin: 'maven-publish'
group = 'de.jottyfan'
-version = '2023.03'
+version = '2023.12'
description = """COJooq"""
-sourceCompatibility = 11
-targetCompatibility = 11
+sourceCompatibility = 17
+targetCompatibility = 17
repositories {
mavenLocal()
@@ -36,18 +36,18 @@ repositories {
}
dependencies {
- implementation 'org.jooq:jooq:3.16.4'
- implementation 'org.jooq:jooq-codegen:3.16.4'
+ implementation 'org.jooq:jooq:latest.release'
+ implementation 'org.jooq:jooq-codegen:latest.release'
- implementation 'org.postgresql:postgresql:42.3.2'
+ implementation 'org.postgresql:postgresql:latest.release'
- jooqGenerator 'org.postgresql:postgresql:42.3.2'
+ jooqGenerator 'org.postgresql:postgresql:latest.release'
}
import org.jooq.meta.jaxb.Logging
jooq {
- version = '3.16.4'
+ version = '3.19.1'
edition = nu.studer.gradle.jooq.JooqEdition.OSS
configurations {
camporganizer {
@@ -56,7 +56,7 @@ jooq {
logging = Logging.WARN
jdbc {
driver = 'org.postgresql.Driver'
- url = 'jdbc:postgresql://localhost:5432/camporganizer'
+ url = 'jdbc:postgresql://localhost:5432/testcamporganizer'
user = 'jooq'
password = 'jooq'
properties {
@@ -76,7 +76,7 @@ jooq {
deprecated = false
relations = true
records = true
- immutablePojos = true
+ immutablePojos = false
fluentSetters = true
}
target {
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/Camp.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/Camp.java
index 9727a40..184a28c 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/Camp.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/Camp.java
@@ -18,8 +18,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.TRss;
import de.jottyfan.camporganizer.db.jooq.tables.TSales;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontent;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontenttype;
-import de.jottyfan.camporganizer.db.jooq.tables.TSalesprofile;
-import de.jottyfan.camporganizer.db.jooq.tables.VAdult;
import de.jottyfan.camporganizer.db.jooq.tables.VBudget;
import de.jottyfan.camporganizer.db.jooq.tables.VCamp;
import de.jottyfan.camporganizer.db.jooq.tables.VCampBudget;
@@ -27,8 +25,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.VCampBudgetYear;
import de.jottyfan.camporganizer.db.jooq.tables.VCampdocument;
import de.jottyfan.camporganizer.db.jooq.tables.VCamprole;
import de.jottyfan.camporganizer.db.jooq.tables.VDocument;
-import de.jottyfan.camporganizer.db.jooq.tables.VDsgvoDeleteCandidate;
-import de.jottyfan.camporganizer.db.jooq.tables.VFeeder;
import de.jottyfan.camporganizer.db.jooq.tables.VProfile;
import de.jottyfan.camporganizer.db.jooq.tables.VRegistration;
import de.jottyfan.camporganizer.db.jooq.tables.VRole;
@@ -126,16 +122,6 @@ public class Camp extends SchemaImpl {
*/
public final TSalescontenttype T_SALESCONTENTTYPE = TSalescontenttype.T_SALESCONTENTTYPE;
- /**
- * The table camp.t_salesprofile
.
- */
- public final TSalesprofile T_SALESPROFILE = TSalesprofile.T_SALESPROFILE;
-
- /**
- * The table camp.v_adult
.
- */
- public final VAdult V_ADULT = VAdult.V_ADULT;
-
/**
* The table camp.v_budget
.
*/
@@ -171,16 +157,6 @@ public class Camp extends SchemaImpl {
*/
public final VDocument V_DOCUMENT = VDocument.V_DOCUMENT;
- /**
- * The table camp.v_dsgvo_delete_candidate
.
- */
- public final VDsgvoDeleteCandidate V_DSGVO_DELETE_CANDIDATE = VDsgvoDeleteCandidate.V_DSGVO_DELETE_CANDIDATE;
-
- /**
- * The table camp.v_feeder
.
- */
- public final VFeeder V_FEEDER = VFeeder.V_FEEDER;
-
/**
* The table camp.v_profile
.
*/
@@ -236,8 +212,6 @@ public class Camp extends SchemaImpl {
TSales.T_SALES,
TSalescontent.T_SALESCONTENT,
TSalescontenttype.T_SALESCONTENTTYPE,
- TSalesprofile.T_SALESPROFILE,
- VAdult.V_ADULT,
VBudget.V_BUDGET,
VCamp.V_CAMP,
VCampBudget.V_CAMP_BUDGET,
@@ -245,8 +219,6 @@ public class Camp extends SchemaImpl {
VCampdocument.V_CAMPDOCUMENT,
VCamprole.V_CAMPROLE,
VDocument.V_DOCUMENT,
- VDsgvoDeleteCandidate.V_DSGVO_DELETE_CANDIDATE,
- VFeeder.V_FEEDER,
VProfile.V_PROFILE,
VRegistration.V_REGISTRATION,
VRole.V_ROLE,
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/Keys.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/Keys.java
index eafd011..8039e1a 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/Keys.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/Keys.java
@@ -18,7 +18,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.TRss;
import de.jottyfan.camporganizer.db.jooq.tables.TSales;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontent;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontenttype;
-import de.jottyfan.camporganizer.db.jooq.tables.TSalesprofile;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampRecord;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampdocumentRecord;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampprofileRecord;
@@ -33,7 +32,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.records.TRssRecord;
import de.jottyfan.camporganizer.db.jooq.tables.records.TSalesRecord;
import de.jottyfan.camporganizer.db.jooq.tables.records.TSalescontentRecord;
import de.jottyfan.camporganizer.db.jooq.tables.records.TSalescontenttypeRecord;
-import de.jottyfan.camporganizer.db.jooq.tables.records.TSalesprofileRecord;
import org.jooq.ForeignKey;
import org.jooq.TableField;
@@ -75,8 +73,6 @@ public class Keys {
public static final UniqueKey T_SALES_PKEY = Internal.createUniqueKey(TSales.T_SALES, DSL.name("t_sales_pkey"), new TableField[] { TSales.T_SALES.PK }, true);
public static final UniqueKey T_SALESCONTENT_FK_SALES_FK_SALESCONTENTTYPE_KEY = Internal.createUniqueKey(TSalescontent.T_SALESCONTENT, DSL.name("t_salescontent_fk_sales_fk_salescontenttype_key"), new TableField[] { TSalescontent.T_SALESCONTENT.FK_SALES, TSalescontent.T_SALESCONTENT.FK_SALESCONTENTTYPE }, true);
public static final UniqueKey T_SALESCONTENTTYPE_PKEY = Internal.createUniqueKey(TSalescontenttype.T_SALESCONTENTTYPE, DSL.name("t_salescontenttype_pkey"), new TableField[] { TSalescontenttype.T_SALESCONTENTTYPE.NAME }, true);
- public static final UniqueKey T_SALESPROFILE_FK_CAMP_FK_PROFILE_KEY = Internal.createUniqueKey(TSalesprofile.T_SALESPROFILE, DSL.name("t_salesprofile_fk_camp_fk_profile_key"), new TableField[] { TSalesprofile.T_SALESPROFILE.FK_CAMP, TSalesprofile.T_SALESPROFILE.FK_PROFILE }, true);
- public static final UniqueKey T_SALESPROFILE_PKEY = Internal.createUniqueKey(TSalesprofile.T_SALESPROFILE, DSL.name("t_salesprofile_pkey"), new TableField[] { TSalesprofile.T_SALESPROFILE.PK }, true);
// -------------------------------------------------------------------------
// FOREIGN KEY definitions
@@ -97,6 +93,4 @@ public class Keys {
public static final ForeignKey T_PERSONDOCUMENT__T_PERSONDOCUMENT_FK_PERSON_FKEY = Internal.createForeignKey(TPersondocument.T_PERSONDOCUMENT, DSL.name("t_persondocument_fk_person_fkey"), new TableField[] { TPersondocument.T_PERSONDOCUMENT.FK_PERSON }, Keys.T_PERSON_PKEY, new TableField[] { TPerson.T_PERSON.PK }, true);
public static final ForeignKey T_PROFILEROLE__T_PROFILEROLE_FK_PROFILE_FKEY = Internal.createForeignKey(TProfilerole.T_PROFILEROLE, DSL.name("t_profilerole_fk_profile_fkey"), new TableField[] { TProfilerole.T_PROFILEROLE.FK_PROFILE }, Keys.T_PROFILE_PKEY, new TableField[] { TProfile.T_PROFILE.PK }, true);
public static final ForeignKey T_SALES__T_SALES_FK_CAMP_FKEY = Internal.createForeignKey(TSales.T_SALES, DSL.name("t_sales_fk_camp_fkey"), new TableField[] { TSales.T_SALES.FK_CAMP }, Keys.T_CAMP_PKEY, new TableField[] { TCamp.T_CAMP.PK }, true);
- public static final ForeignKey T_SALESPROFILE__T_SALESPROFILE_FK_CAMP_FKEY = Internal.createForeignKey(TSalesprofile.T_SALESPROFILE, DSL.name("t_salesprofile_fk_camp_fkey"), new TableField[] { TSalesprofile.T_SALESPROFILE.FK_CAMP }, Keys.T_CAMP_PKEY, new TableField[] { TCamp.T_CAMP.PK }, true);
- public static final ForeignKey T_SALESPROFILE__T_SALESPROFILE_FK_PROFILE_FKEY = Internal.createForeignKey(TSalesprofile.T_SALESPROFILE, DSL.name("t_salesprofile_fk_profile_fkey"), new TableField[] { TSalesprofile.T_SALESPROFILE.FK_PROFILE }, Keys.T_PROFILE_PKEY, new TableField[] { TProfile.T_PROFILE.PK }, true);
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/Tables.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/Tables.java
index 54140d6..811f8a0 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/Tables.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/Tables.java
@@ -18,8 +18,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.TRss;
import de.jottyfan.camporganizer.db.jooq.tables.TSales;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontent;
import de.jottyfan.camporganizer.db.jooq.tables.TSalescontenttype;
-import de.jottyfan.camporganizer.db.jooq.tables.TSalesprofile;
-import de.jottyfan.camporganizer.db.jooq.tables.VAdult;
import de.jottyfan.camporganizer.db.jooq.tables.VBudget;
import de.jottyfan.camporganizer.db.jooq.tables.VCamp;
import de.jottyfan.camporganizer.db.jooq.tables.VCampBudget;
@@ -27,8 +25,6 @@ import de.jottyfan.camporganizer.db.jooq.tables.VCampBudgetYear;
import de.jottyfan.camporganizer.db.jooq.tables.VCampdocument;
import de.jottyfan.camporganizer.db.jooq.tables.VCamprole;
import de.jottyfan.camporganizer.db.jooq.tables.VDocument;
-import de.jottyfan.camporganizer.db.jooq.tables.VDsgvoDeleteCandidate;
-import de.jottyfan.camporganizer.db.jooq.tables.VFeeder;
import de.jottyfan.camporganizer.db.jooq.tables.VProfile;
import de.jottyfan.camporganizer.db.jooq.tables.VRegistration;
import de.jottyfan.camporganizer.db.jooq.tables.VRole;
@@ -112,16 +108,6 @@ public class Tables {
*/
public static final TSalescontenttype T_SALESCONTENTTYPE = TSalescontenttype.T_SALESCONTENTTYPE;
- /**
- * The table camp.t_salesprofile
.
- */
- public static final TSalesprofile T_SALESPROFILE = TSalesprofile.T_SALESPROFILE;
-
- /**
- * The table camp.v_adult
.
- */
- public static final VAdult V_ADULT = VAdult.V_ADULT;
-
/**
* The table camp.v_budget
.
*/
@@ -157,16 +143,6 @@ public class Tables {
*/
public static final VDocument V_DOCUMENT = VDocument.V_DOCUMENT;
- /**
- * The table camp.v_dsgvo_delete_candidate
.
- */
- public static final VDsgvoDeleteCandidate V_DSGVO_DELETE_CANDIDATE = VDsgvoDeleteCandidate.V_DSGVO_DELETE_CANDIDATE;
-
- /**
- * The table camp.v_feeder
.
- */
- public static final VFeeder V_FEEDER = VFeeder.V_FEEDER;
-
/**
* The table camp.v_profile
.
*/
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumCamprole.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumCamprole.java
index 5541112..9ed193d 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumCamprole.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumCamprole.java
@@ -54,7 +54,9 @@ public enum EnumCamprole implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumCamprole lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumCamprole.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumDocument.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumDocument.java
index c207c98..c121b66 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumDocument.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumDocument.java
@@ -50,7 +50,9 @@ public enum EnumDocument implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumDocument lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumDocument.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumFiletype.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumFiletype.java
index f577c90..a987120 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumFiletype.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumFiletype.java
@@ -50,7 +50,9 @@ public enum EnumFiletype implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumFiletype lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumFiletype.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumModule.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumModule.java
index b6c6e4c..3c0ae9b 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumModule.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumModule.java
@@ -48,7 +48,9 @@ public enum EnumModule implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumModule lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumModule.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumRole.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumRole.java
index d448e23..74eafbc 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumRole.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumRole.java
@@ -56,7 +56,9 @@ public enum EnumRole implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumRole lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumRole.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumSex.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumSex.java
index f5fcc15..3bbec97 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumSex.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/enums/EnumSex.java
@@ -48,7 +48,9 @@ public enum EnumSex implements EnumType {
}
/**
- * Lookup a value of this EnumType by its literal
+ * Lookup a value of this EnumType by its literal. Returns
+ * null
, if no such value could be found, see {@link
+ * EnumType#lookupLiteral(Class, String)}.
*/
public static EnumSex lookupLiteral(String literal) {
return EnumType.lookupLiteral(EnumSex.class, literal);
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCamp.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCamp.java
index 1c97e2a..bb03940 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCamp.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCamp.java
@@ -6,19 +6,34 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
+import de.jottyfan.camporganizer.db.jooq.tables.TCampdocument.TCampdocumentPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TCampprofile.TCampprofilePath;
+import de.jottyfan.camporganizer.db.jooq.tables.TDocument.TDocumentPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TLocation.TLocationPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TPerson.TPersonPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TProfile.TProfilePath;
+import de.jottyfan.camporganizer.db.jooq.tables.TSales.TSalesPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampRecord;
import java.time.LocalDateTime;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row12;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -102,7 +117,7 @@ public class TCamp extends TableImpl {
/**
* The column camp.t_camp.lock_sales
.
*/
- public final TableField LOCK_SALES = createField(DSL.name("lock_sales"), SQLDataType.BOOLEAN.nullable(false).defaultValue(DSL.field("false", SQLDataType.BOOLEAN)), this, "");
+ public final TableField LOCK_SALES = createField(DSL.name("lock_sales"), SQLDataType.BOOLEAN.nullable(false).defaultValue(DSL.field(DSL.raw("false"), SQLDataType.BOOLEAN)), this, "");
/**
* The column camp.t_camp.fk_profile
.
@@ -110,11 +125,11 @@ public class TCamp extends TableImpl {
public final TableField FK_PROFILE = createField(DSL.name("fk_profile"), SQLDataType.INTEGER.nullable(false), this, "");
private TCamp(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TCamp(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TCamp(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -138,8 +153,35 @@ public class TCamp extends TableImpl {
this(DSL.name("t_camp"), null);
}
- public TCamp(Table child, ForeignKey key) {
- super(child, key, T_CAMP);
+ public TCamp(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_CAMP);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TCampPath extends TCamp implements Path {
+ public TCampPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TCampPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TCampPath as(String alias) {
+ return new TCampPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TCampPath as(Name alias) {
+ return new TCampPath(alias, this);
+ }
+
+ @Override
+ public TCampPath as(Table> alias) {
+ return new TCampPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -162,40 +204,93 @@ public class TCamp extends TableImpl {
return Arrays.asList(Keys.T_CAMP__T_CAMP_FK_LOCATION_FKEY, Keys.T_CAMP__T_CAMP_FK_DOCUMENT_FKEY, Keys.T_CAMP__T_CAMP_FK_PROFILE_FKEY);
}
- private transient TLocation _tLocation;
- private transient TDocument _tDocument;
- private transient TProfile _tProfile;
+ private transient TLocationPath _tLocation;
/**
* Get the implicit join path to the camp.t_location
table.
*/
- public TLocation tLocation() {
+ public TLocationPath tLocation() {
if (_tLocation == null)
- _tLocation = new TLocation(this, Keys.T_CAMP__T_CAMP_FK_LOCATION_FKEY);
+ _tLocation = new TLocationPath(this, Keys.T_CAMP__T_CAMP_FK_LOCATION_FKEY, null);
return _tLocation;
}
+ private transient TDocumentPath _tDocument;
+
/**
* Get the implicit join path to the camp.t_document
table.
*/
- public TDocument tDocument() {
+ public TDocumentPath tDocument() {
if (_tDocument == null)
- _tDocument = new TDocument(this, Keys.T_CAMP__T_CAMP_FK_DOCUMENT_FKEY);
+ _tDocument = new TDocumentPath(this, Keys.T_CAMP__T_CAMP_FK_DOCUMENT_FKEY, null);
return _tDocument;
}
+ private transient TProfilePath _tProfile;
+
/**
* Get the implicit join path to the camp.t_profile
table.
*/
- public TProfile tProfile() {
+ public TProfilePath tProfile() {
if (_tProfile == null)
- _tProfile = new TProfile(this, Keys.T_CAMP__T_CAMP_FK_PROFILE_FKEY);
+ _tProfile = new TProfilePath(this, Keys.T_CAMP__T_CAMP_FK_PROFILE_FKEY, null);
return _tProfile;
}
+ private transient TCampdocumentPath _tCampdocument;
+
+ /**
+ * Get the implicit to-many join path to the
+ * camp.t_campdocument
table
+ */
+ public TCampdocumentPath tCampdocument() {
+ if (_tCampdocument == null)
+ _tCampdocument = new TCampdocumentPath(this, null, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_CAMP_FKEY.getInverseKey());
+
+ return _tCampdocument;
+ }
+
+ private transient TCampprofilePath _tCampprofile;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_campprofile
+ * table
+ */
+ public TCampprofilePath tCampprofile() {
+ if (_tCampprofile == null)
+ _tCampprofile = new TCampprofilePath(this, null, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_CAMP_FKEY.getInverseKey());
+
+ return _tCampprofile;
+ }
+
+ private transient TPersonPath _tPerson;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_person
+ * table
+ */
+ public TPersonPath tPerson() {
+ if (_tPerson == null)
+ _tPerson = new TPersonPath(this, null, Keys.T_PERSON__T_PERSON_FK_CAMP_FKEY.getInverseKey());
+
+ return _tPerson;
+ }
+
+ private transient TSalesPath _tSales;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_sales
table
+ */
+ public TSalesPath tSales() {
+ if (_tSales == null)
+ _tSales = new TSalesPath(this, null, Keys.T_SALES__T_SALES_FK_CAMP_FKEY.getInverseKey());
+
+ return _tSales;
+ }
+
@Override
public TCamp as(String alias) {
return new TCamp(DSL.name(alias), this);
@@ -206,6 +301,11 @@ public class TCamp extends TableImpl {
return new TCamp(alias, this);
}
+ @Override
+ public TCamp as(Table> alias) {
+ return new TCamp(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -222,12 +322,95 @@ public class TCamp extends TableImpl {
return new TCamp(name, null);
}
- // -------------------------------------------------------------------------
- // Row12 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row12 fieldsRow() {
- return (Row12) super.fieldsRow();
+ public TCamp rename(Table> name) {
+ return new TCamp(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp where(Condition condition) {
+ return new TCamp(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCamp where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCamp where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCamp where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCamp where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCamp whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampdocument.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampdocument.java
index d7b3289..219cce5 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampdocument.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampdocument.java
@@ -6,18 +6,28 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TDocument.TDocumentPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampdocumentRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row3;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -64,11 +74,11 @@ public class TCampdocument extends TableImpl {
public final TableField FK_DOCUMENT = createField(DSL.name("fk_document"), SQLDataType.INTEGER.nullable(false), this, "");
private TCampdocument(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TCampdocument(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TCampdocument(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -92,8 +102,35 @@ public class TCampdocument extends TableImpl {
this(DSL.name("t_campdocument"), null);
}
- public TCampdocument(Table child, ForeignKey key) {
- super(child, key, T_CAMPDOCUMENT);
+ public TCampdocument(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_CAMPDOCUMENT);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TCampdocumentPath extends TCampdocument implements Path {
+ public TCampdocumentPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TCampdocumentPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TCampdocumentPath as(String alias) {
+ return new TCampdocumentPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TCampdocumentPath as(Name alias) {
+ return new TCampdocumentPath(alias, this);
+ }
+
+ @Override
+ public TCampdocumentPath as(Table> alias) {
+ return new TCampdocumentPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -121,25 +158,26 @@ public class TCampdocument extends TableImpl {
return Arrays.asList(Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_CAMP_FKEY, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_DOCUMENT_FKEY);
}
- private transient TCamp _tCamp;
- private transient TDocument _tDocument;
+ private transient TCampPath _tCamp;
/**
* Get the implicit join path to the camp.t_camp
table.
*/
- public TCamp tCamp() {
+ public TCampPath tCamp() {
if (_tCamp == null)
- _tCamp = new TCamp(this, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_CAMP_FKEY);
+ _tCamp = new TCampPath(this, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_CAMP_FKEY, null);
return _tCamp;
}
+ private transient TDocumentPath _tDocument;
+
/**
* Get the implicit join path to the camp.t_document
table.
*/
- public TDocument tDocument() {
+ public TDocumentPath tDocument() {
if (_tDocument == null)
- _tDocument = new TDocument(this, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_DOCUMENT_FKEY);
+ _tDocument = new TDocumentPath(this, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_DOCUMENT_FKEY, null);
return _tDocument;
}
@@ -154,6 +192,11 @@ public class TCampdocument extends TableImpl {
return new TCampdocument(alias, this);
}
+ @Override
+ public TCampdocument as(Table> alias) {
+ return new TCampdocument(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -170,12 +213,95 @@ public class TCampdocument extends TableImpl {
return new TCampdocument(name, null);
}
- // -------------------------------------------------------------------------
- // Row3 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row3 fieldsRow() {
- return (Row3) super.fieldsRow();
+ public TCampdocument rename(Table> name) {
+ return new TCampdocument(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument where(Condition condition) {
+ return new TCampdocument(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampdocument where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampdocument where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampdocument where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampdocument where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampdocument whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampprofile.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampprofile.java
index 583f863..9748fa7 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampprofile.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TCampprofile.java
@@ -7,18 +7,28 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumModule;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TProfile.TProfilePath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TCampprofileRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row4;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -67,14 +77,14 @@ public class TCampprofile extends TableImpl {
/**
* The column camp.t_campprofile.module
.
*/
- public final TableField MODULE = createField(DSL.name("module"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumModule.class), this, "");
+ public final TableField MODULE = createField(DSL.name("module"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(EnumModule.class), this, "");
private TCampprofile(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TCampprofile(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TCampprofile(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -98,8 +108,35 @@ public class TCampprofile extends TableImpl {
this(DSL.name("t_campprofile"), null);
}
- public TCampprofile(Table child, ForeignKey key) {
- super(child, key, T_CAMPPROFILE);
+ public TCampprofile(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_CAMPPROFILE);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TCampprofilePath extends TCampprofile implements Path {
+ public TCampprofilePath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TCampprofilePath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TCampprofilePath as(String alias) {
+ return new TCampprofilePath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TCampprofilePath as(Name alias) {
+ return new TCampprofilePath(alias, this);
+ }
+
+ @Override
+ public TCampprofilePath as(Table> alias) {
+ return new TCampprofilePath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -127,25 +164,26 @@ public class TCampprofile extends TableImpl {
return Arrays.asList(Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_PROFILE_FKEY, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_CAMP_FKEY);
}
- private transient TProfile _tProfile;
- private transient TCamp _tCamp;
+ private transient TProfilePath _tProfile;
/**
* Get the implicit join path to the camp.t_profile
table.
*/
- public TProfile tProfile() {
+ public TProfilePath tProfile() {
if (_tProfile == null)
- _tProfile = new TProfile(this, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_PROFILE_FKEY);
+ _tProfile = new TProfilePath(this, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_PROFILE_FKEY, null);
return _tProfile;
}
+ private transient TCampPath _tCamp;
+
/**
* Get the implicit join path to the camp.t_camp
table.
*/
- public TCamp tCamp() {
+ public TCampPath tCamp() {
if (_tCamp == null)
- _tCamp = new TCamp(this, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_CAMP_FKEY);
+ _tCamp = new TCampPath(this, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_CAMP_FKEY, null);
return _tCamp;
}
@@ -160,6 +198,11 @@ public class TCampprofile extends TableImpl {
return new TCampprofile(alias, this);
}
+ @Override
+ public TCampprofile as(Table> alias) {
+ return new TCampprofile(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -176,12 +219,95 @@ public class TCampprofile extends TableImpl {
return new TCampprofile(name, null);
}
- // -------------------------------------------------------------------------
- // Row4 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row4 fieldsRow() {
- return (Row4) super.fieldsRow();
+ public TCampprofile rename(Table> name) {
+ return new TCampprofile(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile where(Condition condition) {
+ return new TCampprofile(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampprofile where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampprofile where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampprofile where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TCampprofile where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TCampprofile whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocument.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocument.java
index 4cb774d..0d30d39 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocument.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocument.java
@@ -8,18 +8,30 @@ import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumDocument;
import de.jottyfan.camporganizer.db.jooq.enums.EnumFiletype;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TCampdocument.TCampdocumentPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TDocumentrole.TDocumentrolePath;
+import de.jottyfan.camporganizer.db.jooq.tables.TLocation.TLocationPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TDocumentRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row5;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -58,7 +70,7 @@ public class TDocument extends TableImpl {
/**
* The column camp.t_document.doctype
.
*/
- public final TableField DOCTYPE = createField(DSL.name("doctype"), SQLDataType.VARCHAR.asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumDocument.class), this, "");
+ public final TableField DOCTYPE = createField(DSL.name("doctype"), SQLDataType.VARCHAR.asEnumDataType(EnumDocument.class), this, "");
/**
* The column camp.t_document.name
.
@@ -73,14 +85,14 @@ public class TDocument extends TableImpl {
/**
* The column camp.t_document.filetype
.
*/
- public final TableField FILETYPE = createField(DSL.name("filetype"), SQLDataType.VARCHAR.asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumFiletype.class), this, "");
+ public final TableField FILETYPE = createField(DSL.name("filetype"), SQLDataType.VARCHAR.asEnumDataType(EnumFiletype.class), this, "");
private TDocument(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TDocument(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TDocument(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -104,8 +116,35 @@ public class TDocument extends TableImpl {
this(DSL.name("t_document"), null);
}
- public TDocument(Table child, ForeignKey key) {
- super(child, key, T_DOCUMENT);
+ public TDocument(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_DOCUMENT);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TDocumentPath extends TDocument implements Path {
+ public TDocumentPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TDocumentPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TDocumentPath as(String alias) {
+ return new TDocumentPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TDocumentPath as(Name alias) {
+ return new TDocumentPath(alias, this);
+ }
+
+ @Override
+ public TDocumentPath as(Table> alias) {
+ return new TDocumentPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -128,6 +167,57 @@ public class TDocument extends TableImpl {
return Arrays.asList(Keys.T_DOCUMENT_NAME_KEY);
}
+ private transient TCampPath _tCamp;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_camp
table
+ */
+ public TCampPath tCamp() {
+ if (_tCamp == null)
+ _tCamp = new TCampPath(this, null, Keys.T_CAMP__T_CAMP_FK_DOCUMENT_FKEY.getInverseKey());
+
+ return _tCamp;
+ }
+
+ private transient TCampdocumentPath _tCampdocument;
+
+ /**
+ * Get the implicit to-many join path to the
+ * camp.t_campdocument
table
+ */
+ public TCampdocumentPath tCampdocument() {
+ if (_tCampdocument == null)
+ _tCampdocument = new TCampdocumentPath(this, null, Keys.T_CAMPDOCUMENT__T_CAMPDOCUMENT_FK_DOCUMENT_FKEY.getInverseKey());
+
+ return _tCampdocument;
+ }
+
+ private transient TDocumentrolePath _tDocumentrole;
+
+ /**
+ * Get the implicit to-many join path to the
+ * camp.t_documentrole
table
+ */
+ public TDocumentrolePath tDocumentrole() {
+ if (_tDocumentrole == null)
+ _tDocumentrole = new TDocumentrolePath(this, null, Keys.T_DOCUMENTROLE__T_DOCUMENTROLE_FK_DOCUMENT_FKEY.getInverseKey());
+
+ return _tDocumentrole;
+ }
+
+ private transient TLocationPath _tLocation;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_location
+ * table
+ */
+ public TLocationPath tLocation() {
+ if (_tLocation == null)
+ _tLocation = new TLocationPath(this, null, Keys.T_LOCATION__T_LOCATION_FK_DOCUMENT_FKEY.getInverseKey());
+
+ return _tLocation;
+ }
+
@Override
public TDocument as(String alias) {
return new TDocument(DSL.name(alias), this);
@@ -138,6 +228,11 @@ public class TDocument extends TableImpl {
return new TDocument(alias, this);
}
+ @Override
+ public TDocument as(Table> alias) {
+ return new TDocument(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -154,12 +249,95 @@ public class TDocument extends TableImpl {
return new TDocument(name, null);
}
- // -------------------------------------------------------------------------
- // Row5 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row5 fieldsRow() {
- return (Row5) super.fieldsRow();
+ public TDocument rename(Table> name) {
+ return new TDocument(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument where(Condition condition) {
+ return new TDocument(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocument where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocument where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocument where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocument where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocument whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocumentrole.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocumentrole.java
index ea12575..7723659 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocumentrole.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TDocumentrole.java
@@ -7,18 +7,27 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumCamprole;
+import de.jottyfan.camporganizer.db.jooq.tables.TDocument.TDocumentPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TDocumentroleRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row3;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -62,14 +71,14 @@ public class TDocumentrole extends TableImpl {
/**
* The column camp.t_documentrole.camprole
.
*/
- public final TableField CAMPROLE = createField(DSL.name("camprole"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumCamprole.class), this, "");
+ public final TableField CAMPROLE = createField(DSL.name("camprole"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(EnumCamprole.class), this, "");
private TDocumentrole(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TDocumentrole(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TDocumentrole(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -93,8 +102,35 @@ public class TDocumentrole extends TableImpl {
this(DSL.name("t_documentrole"), null);
}
- public TDocumentrole(Table child, ForeignKey key) {
- super(child, key, T_DOCUMENTROLE);
+ public TDocumentrole(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_DOCUMENTROLE);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TDocumentrolePath extends TDocumentrole implements Path {
+ public TDocumentrolePath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TDocumentrolePath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TDocumentrolePath as(String alias) {
+ return new TDocumentrolePath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TDocumentrolePath as(Name alias) {
+ return new TDocumentrolePath(alias, this);
+ }
+
+ @Override
+ public TDocumentrolePath as(Table> alias) {
+ return new TDocumentrolePath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -122,14 +158,14 @@ public class TDocumentrole extends TableImpl {
return Arrays.asList(Keys.T_DOCUMENTROLE__T_DOCUMENTROLE_FK_DOCUMENT_FKEY);
}
- private transient TDocument _tDocument;
+ private transient TDocumentPath _tDocument;
/**
* Get the implicit join path to the camp.t_document
table.
*/
- public TDocument tDocument() {
+ public TDocumentPath tDocument() {
if (_tDocument == null)
- _tDocument = new TDocument(this, Keys.T_DOCUMENTROLE__T_DOCUMENTROLE_FK_DOCUMENT_FKEY);
+ _tDocument = new TDocumentPath(this, Keys.T_DOCUMENTROLE__T_DOCUMENTROLE_FK_DOCUMENT_FKEY, null);
return _tDocument;
}
@@ -144,6 +180,11 @@ public class TDocumentrole extends TableImpl {
return new TDocumentrole(alias, this);
}
+ @Override
+ public TDocumentrole as(Table> alias) {
+ return new TDocumentrole(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -160,12 +201,95 @@ public class TDocumentrole extends TableImpl {
return new TDocumentrole(name, null);
}
- // -------------------------------------------------------------------------
- // Row3 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row3 fieldsRow() {
- return (Row3) super.fieldsRow();
+ public TDocumentrole rename(Table> name) {
+ return new TDocumentrole(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole where(Condition condition) {
+ return new TDocumentrole(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocumentrole where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocumentrole where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocumentrole where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TDocumentrole where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TDocumentrole whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TLocation.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TLocation.java
index 6eefee0..2a0aa61 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TLocation.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TLocation.java
@@ -6,18 +6,28 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TDocument.TDocumentPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TLocationRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row4;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -69,11 +79,11 @@ public class TLocation extends TableImpl {
public final TableField FK_DOCUMENT = createField(DSL.name("fk_document"), SQLDataType.INTEGER, this, "");
private TLocation(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TLocation(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TLocation(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -97,8 +107,35 @@ public class TLocation extends TableImpl {
this(DSL.name("t_location"), null);
}
- public TLocation(Table child, ForeignKey key) {
- super(child, key, T_LOCATION);
+ public TLocation(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_LOCATION);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TLocationPath extends TLocation implements Path {
+ public TLocationPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TLocationPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TLocationPath as(String alias) {
+ return new TLocationPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TLocationPath as(Name alias) {
+ return new TLocationPath(alias, this);
+ }
+
+ @Override
+ public TLocationPath as(Table> alias) {
+ return new TLocationPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -121,18 +158,30 @@ public class TLocation extends TableImpl {
return Arrays.asList(Keys.T_LOCATION__T_LOCATION_FK_DOCUMENT_FKEY);
}
- private transient TDocument _tDocument;
+ private transient TDocumentPath _tDocument;
/**
* Get the implicit join path to the camp.t_document
table.
*/
- public TDocument tDocument() {
+ public TDocumentPath tDocument() {
if (_tDocument == null)
- _tDocument = new TDocument(this, Keys.T_LOCATION__T_LOCATION_FK_DOCUMENT_FKEY);
+ _tDocument = new TDocumentPath(this, Keys.T_LOCATION__T_LOCATION_FK_DOCUMENT_FKEY, null);
return _tDocument;
}
+ private transient TCampPath _tCamp;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_camp
table
+ */
+ public TCampPath tCamp() {
+ if (_tCamp == null)
+ _tCamp = new TCampPath(this, null, Keys.T_CAMP__T_CAMP_FK_LOCATION_FKEY.getInverseKey());
+
+ return _tCamp;
+ }
+
@Override
public TLocation as(String alias) {
return new TLocation(DSL.name(alias), this);
@@ -143,6 +192,11 @@ public class TLocation extends TableImpl {
return new TLocation(alias, this);
}
+ @Override
+ public TLocation as(Table> alias) {
+ return new TLocation(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -159,12 +213,95 @@ public class TLocation extends TableImpl {
return new TLocation(name, null);
}
- // -------------------------------------------------------------------------
- // Row4 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row4 fieldsRow() {
- return (Row4) super.fieldsRow();
+ public TLocation rename(Table> name) {
+ return new TLocation(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation where(Condition condition) {
+ return new TLocation(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TLocation where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TLocation where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TLocation where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TLocation where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TLocation whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPerson.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPerson.java
index 882baf9..f10752d 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPerson.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPerson.java
@@ -8,21 +8,32 @@ import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumCamprole;
import de.jottyfan.camporganizer.db.jooq.enums.EnumSex;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TPersondocument.TPersondocumentPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TProfile.TProfilePath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TPersonRecord;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row20;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -96,7 +107,7 @@ public class TPerson extends TableImpl {
/**
* The column camp.t_person.camprole
.
*/
- public final TableField CAMPROLE = createField(DSL.name("camprole"), SQLDataType.VARCHAR.asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumCamprole.class), this, "");
+ public final TableField CAMPROLE = createField(DSL.name("camprole"), SQLDataType.VARCHAR.asEnumDataType(EnumCamprole.class), this, "");
/**
* The column camp.t_person.email
.
@@ -121,12 +132,12 @@ public class TPerson extends TableImpl {
/**
* The column camp.t_person.created
.
*/
- public final TableField CREATED = createField(DSL.name("created"), SQLDataType.LOCALDATETIME(6).defaultValue(DSL.field("now()", SQLDataType.LOCALDATETIME)), this, "");
+ public final TableField CREATED = createField(DSL.name("created"), SQLDataType.LOCALDATETIME(6).defaultValue(DSL.field(DSL.raw("now()"), SQLDataType.LOCALDATETIME)), this, "");
/**
* The column camp.t_person.sex
.
*/
- public final TableField SEX = createField(DSL.name("sex"), SQLDataType.VARCHAR.asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumSex.class), this, "");
+ public final TableField SEX = createField(DSL.name("sex"), SQLDataType.VARCHAR.asEnumDataType(EnumSex.class), this, "");
/**
* The column camp.t_person.fk_registrator
.
@@ -146,7 +157,7 @@ public class TPerson extends TableImpl {
/**
* The column camp.t_person.consent_catalog_photo
.
*/
- public final TableField CONSENT_CATALOG_PHOTO = createField(DSL.name("consent_catalog_photo"), SQLDataType.BOOLEAN.nullable(false).defaultValue(DSL.field("false", SQLDataType.BOOLEAN)), this, "");
+ public final TableField CONSENT_CATALOG_PHOTO = createField(DSL.name("consent_catalog_photo"), SQLDataType.BOOLEAN.nullable(false).defaultValue(DSL.field(DSL.raw("false"), SQLDataType.BOOLEAN)), this, "");
/**
* The column camp.t_person.required_price
.
@@ -154,11 +165,11 @@ public class TPerson extends TableImpl {
public final TableField REQUIRED_PRICE = createField(DSL.name("required_price"), SQLDataType.NUMERIC(7, 2), this, "");
private TPerson(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TPerson(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TPerson(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -182,8 +193,35 @@ public class TPerson extends TableImpl {
this(DSL.name("t_person"), null);
}
- public TPerson(Table child, ForeignKey key) {
- super(child, key, T_PERSON);
+ public TPerson(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_PERSON);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TPersonPath extends TPerson implements Path {
+ public TPersonPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TPersonPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TPersonPath as(String alias) {
+ return new TPersonPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TPersonPath as(Name alias) {
+ return new TPersonPath(alias, this);
+ }
+
+ @Override
+ public TPersonPath as(Table> alias) {
+ return new TPersonPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -211,42 +249,57 @@ public class TPerson extends TableImpl {
return Arrays.asList(Keys.T_PERSON__T_PERSON_FK_CAMP_FKEY, Keys.T_PERSON__T_PERSON_FK_PROFILE_FKEY, Keys.T_PERSON__T_PERSON_FK_REGISTRATOR_FKEY);
}
- private transient TCamp _tCamp;
- private transient TProfile _tPersonFkProfileFkey;
- private transient TProfile _tPersonFkRegistratorFkey;
+ private transient TCampPath _tCamp;
/**
* Get the implicit join path to the camp.t_camp
table.
*/
- public TCamp tCamp() {
+ public TCampPath tCamp() {
if (_tCamp == null)
- _tCamp = new TCamp(this, Keys.T_PERSON__T_PERSON_FK_CAMP_FKEY);
+ _tCamp = new TCampPath(this, Keys.T_PERSON__T_PERSON_FK_CAMP_FKEY, null);
return _tCamp;
}
+ private transient TProfilePath _tPersonFkProfileFkey;
+
/**
* Get the implicit join path to the camp.t_profile
table, via
* the t_person_fk_profile_fkey
key.
*/
- public TProfile tPersonFkProfileFkey() {
+ public TProfilePath tPersonFkProfileFkey() {
if (_tPersonFkProfileFkey == null)
- _tPersonFkProfileFkey = new TProfile(this, Keys.T_PERSON__T_PERSON_FK_PROFILE_FKEY);
+ _tPersonFkProfileFkey = new TProfilePath(this, Keys.T_PERSON__T_PERSON_FK_PROFILE_FKEY, null);
return _tPersonFkProfileFkey;
}
+ private transient TProfilePath _tPersonFkRegistratorFkey;
+
/**
* Get the implicit join path to the camp.t_profile
table, via
* the t_person_fk_registrator_fkey
key.
*/
- public TProfile tPersonFkRegistratorFkey() {
+ public TProfilePath tPersonFkRegistratorFkey() {
if (_tPersonFkRegistratorFkey == null)
- _tPersonFkRegistratorFkey = new TProfile(this, Keys.T_PERSON__T_PERSON_FK_REGISTRATOR_FKEY);
+ _tPersonFkRegistratorFkey = new TProfilePath(this, Keys.T_PERSON__T_PERSON_FK_REGISTRATOR_FKEY, null);
return _tPersonFkRegistratorFkey;
}
+ private transient TPersondocumentPath _tPersondocument;
+
+ /**
+ * Get the implicit to-many join path to the
+ * camp.t_persondocument
table
+ */
+ public TPersondocumentPath tPersondocument() {
+ if (_tPersondocument == null)
+ _tPersondocument = new TPersondocumentPath(this, null, Keys.T_PERSONDOCUMENT__T_PERSONDOCUMENT_FK_PERSON_FKEY.getInverseKey());
+
+ return _tPersondocument;
+ }
+
@Override
public TPerson as(String alias) {
return new TPerson(DSL.name(alias), this);
@@ -257,6 +310,11 @@ public class TPerson extends TableImpl {
return new TPerson(alias, this);
}
+ @Override
+ public TPerson as(Table> alias) {
+ return new TPerson(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -273,12 +331,95 @@ public class TPerson extends TableImpl {
return new TPerson(name, null);
}
- // -------------------------------------------------------------------------
- // Row20 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row20 fieldsRow() {
- return (Row20) super.fieldsRow();
+ public TPerson rename(Table> name) {
+ return new TPerson(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson where(Condition condition) {
+ return new TPerson(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPerson where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPerson where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPerson where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPerson where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPerson whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPersondocument.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPersondocument.java
index 93a1ed4..2d501b5 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPersondocument.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TPersondocument.java
@@ -7,18 +7,27 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumFiletype;
+import de.jottyfan.camporganizer.db.jooq.tables.TPerson.TPersonPath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TPersondocumentRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row5;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -72,14 +81,14 @@ public class TPersondocument extends TableImpl {
/**
* The column camp.t_persondocument.filetype
.
*/
- public final TableField FILETYPE = createField(DSL.name("filetype"), SQLDataType.VARCHAR.asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumFiletype.class), this, "");
+ public final TableField FILETYPE = createField(DSL.name("filetype"), SQLDataType.VARCHAR.asEnumDataType(EnumFiletype.class), this, "");
private TPersondocument(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TPersondocument(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TPersondocument(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -103,8 +112,35 @@ public class TPersondocument extends TableImpl {
this(DSL.name("t_persondocument"), null);
}
- public TPersondocument(Table child, ForeignKey key) {
- super(child, key, T_PERSONDOCUMENT);
+ public TPersondocument(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_PERSONDOCUMENT);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TPersondocumentPath extends TPersondocument implements Path {
+ public TPersondocumentPath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TPersondocumentPath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TPersondocumentPath as(String alias) {
+ return new TPersondocumentPath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TPersondocumentPath as(Name alias) {
+ return new TPersondocumentPath(alias, this);
+ }
+
+ @Override
+ public TPersondocumentPath as(Table> alias) {
+ return new TPersondocumentPath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -132,14 +168,14 @@ public class TPersondocument extends TableImpl {
return Arrays.asList(Keys.T_PERSONDOCUMENT__T_PERSONDOCUMENT_FK_PERSON_FKEY);
}
- private transient TPerson _tPerson;
+ private transient TPersonPath _tPerson;
/**
* Get the implicit join path to the camp.t_person
table.
*/
- public TPerson tPerson() {
+ public TPersonPath tPerson() {
if (_tPerson == null)
- _tPerson = new TPerson(this, Keys.T_PERSONDOCUMENT__T_PERSONDOCUMENT_FK_PERSON_FKEY);
+ _tPerson = new TPersonPath(this, Keys.T_PERSONDOCUMENT__T_PERSONDOCUMENT_FK_PERSON_FKEY, null);
return _tPerson;
}
@@ -154,6 +190,11 @@ public class TPersondocument extends TableImpl {
return new TPersondocument(alias, this);
}
+ @Override
+ public TPersondocument as(Table> alias) {
+ return new TPersondocument(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -170,12 +211,95 @@ public class TPersondocument extends TableImpl {
return new TPersondocument(name, null);
}
- // -------------------------------------------------------------------------
- // Row5 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row5 fieldsRow() {
- return (Row5) super.fieldsRow();
+ public TPersondocument rename(Table> name) {
+ return new TPersondocument(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument where(Condition condition) {
+ return new TPersondocument(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPersondocument where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPersondocument where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPersondocument where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TPersondocument where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TPersondocument whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfile.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfile.java
index 710bce6..59978f8 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfile.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfile.java
@@ -6,19 +6,31 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
+import de.jottyfan.camporganizer.db.jooq.tables.TCamp.TCampPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TCampprofile.TCampprofilePath;
+import de.jottyfan.camporganizer.db.jooq.tables.TPerson.TPersonPath;
+import de.jottyfan.camporganizer.db.jooq.tables.TProfilerole.TProfilerolePath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TProfileRecord;
import java.time.LocalDateTime;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
import org.jooq.Identity;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row7;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -77,7 +89,7 @@ public class TProfile extends TableImpl {
/**
* The column camp.t_profile.duedate
.
*/
- public final TableField DUEDATE = createField(DSL.name("duedate"), SQLDataType.LOCALDATETIME(6).defaultValue(DSL.field("(now() + '1 year'::interval)", SQLDataType.LOCALDATETIME)), this, "");
+ public final TableField DUEDATE = createField(DSL.name("duedate"), SQLDataType.LOCALDATETIME(6).defaultValue(DSL.field(DSL.raw("(now() + '1 year'::interval)"), SQLDataType.LOCALDATETIME)), this, "");
/**
* The column camp.t_profile.uuid
.
@@ -85,11 +97,11 @@ public class TProfile extends TableImpl {
public final TableField UUID = createField(DSL.name("uuid"), SQLDataType.CLOB.nullable(false), this, "");
private TProfile(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TProfile(Name alias, Table aliased, Field>[] parameters) {
- super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table());
+ private TProfile(Name alias, Table aliased, Field>[] parameters, Condition where) {
+ super(alias, null, aliased, parameters, DSL.comment(""), TableOptions.table(), where);
}
/**
@@ -113,8 +125,35 @@ public class TProfile extends TableImpl {
this(DSL.name("t_profile"), null);
}
- public TProfile(Table child, ForeignKey key) {
- super(child, key, T_PROFILE);
+ public TProfile(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath, T_PROFILE);
+ }
+
+ /**
+ * A subtype implementing {@link Path} for simplified path-based joins.
+ */
+ public static class TProfilePath extends TProfile implements Path {
+ public TProfilePath(Table path, ForeignKey childPath, InverseForeignKey parentPath) {
+ super(path, childPath, parentPath);
+ }
+ private TProfilePath(Name alias, Table aliased) {
+ super(alias, aliased);
+ }
+
+ @Override
+ public TProfilePath as(String alias) {
+ return new TProfilePath(DSL.name(alias), this);
+ }
+
+ @Override
+ public TProfilePath as(Name alias) {
+ return new TProfilePath(alias, this);
+ }
+
+ @Override
+ public TProfilePath as(Table> alias) {
+ return new TProfilePath(alias.getQualifiedName(), this);
+ }
}
@Override
@@ -137,6 +176,70 @@ public class TProfile extends TableImpl {
return Arrays.asList(Keys.T_PROFILE_USERNAME_KEY, Keys.T_PROFILE_UUID_KEY);
}
+ private transient TCampPath _tCamp;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_camp
table
+ */
+ public TCampPath tCamp() {
+ if (_tCamp == null)
+ _tCamp = new TCampPath(this, null, Keys.T_CAMP__T_CAMP_FK_PROFILE_FKEY.getInverseKey());
+
+ return _tCamp;
+ }
+
+ private transient TCampprofilePath _tCampprofile;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_campprofile
+ * table
+ */
+ public TCampprofilePath tCampprofile() {
+ if (_tCampprofile == null)
+ _tCampprofile = new TCampprofilePath(this, null, Keys.T_CAMPPROFILE__T_CAMPPROFILE_FK_PROFILE_FKEY.getInverseKey());
+
+ return _tCampprofile;
+ }
+
+ private transient TPersonPath _tPersonFkProfileFkey;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_person
+ * table, via the t_person_fk_profile_fkey
key
+ */
+ public TPersonPath tPersonFkProfileFkey() {
+ if (_tPersonFkProfileFkey == null)
+ _tPersonFkProfileFkey = new TPersonPath(this, null, Keys.T_PERSON__T_PERSON_FK_PROFILE_FKEY.getInverseKey());
+
+ return _tPersonFkProfileFkey;
+ }
+
+ private transient TPersonPath _tPersonFkRegistratorFkey;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_person
+ * table, via the t_person_fk_registrator_fkey
key
+ */
+ public TPersonPath tPersonFkRegistratorFkey() {
+ if (_tPersonFkRegistratorFkey == null)
+ _tPersonFkRegistratorFkey = new TPersonPath(this, null, Keys.T_PERSON__T_PERSON_FK_REGISTRATOR_FKEY.getInverseKey());
+
+ return _tPersonFkRegistratorFkey;
+ }
+
+ private transient TProfilerolePath _tProfilerole;
+
+ /**
+ * Get the implicit to-many join path to the camp.t_profilerole
+ * table
+ */
+ public TProfilerolePath tProfilerole() {
+ if (_tProfilerole == null)
+ _tProfilerole = new TProfilerolePath(this, null, Keys.T_PROFILEROLE__T_PROFILEROLE_FK_PROFILE_FKEY.getInverseKey());
+
+ return _tProfilerole;
+ }
+
@Override
public TProfile as(String alias) {
return new TProfile(DSL.name(alias), this);
@@ -147,6 +250,11 @@ public class TProfile extends TableImpl {
return new TProfile(alias, this);
}
+ @Override
+ public TProfile as(Table> alias) {
+ return new TProfile(alias.getQualifiedName(), this);
+ }
+
/**
* Rename this table
*/
@@ -163,12 +271,95 @@ public class TProfile extends TableImpl {
return new TProfile(name, null);
}
- // -------------------------------------------------------------------------
- // Row7 type methods
- // -------------------------------------------------------------------------
-
+ /**
+ * Rename this table
+ */
@Override
- public Row7 fieldsRow() {
- return (Row7) super.fieldsRow();
+ public TProfile rename(Table> name) {
+ return new TProfile(name.getQualifiedName(), null);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile where(Condition condition) {
+ return new TProfile(getQualifiedName(), aliased() ? this : null, null, condition);
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile where(Collection extends Condition> conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile where(Condition... conditions) {
+ return where(DSL.and(conditions));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile where(Field condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TProfile where(SQL condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TProfile where(@Stringly.SQL String condition) {
+ return where(DSL.condition(condition));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TProfile where(@Stringly.SQL String condition, Object... binds) {
+ return where(DSL.condition(condition, binds));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ @PlainSQL
+ public TProfile where(@Stringly.SQL String condition, QueryPart... parts) {
+ return where(DSL.condition(condition, parts));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile whereExists(Select> select) {
+ return where(DSL.exists(select));
+ }
+
+ /**
+ * Create an inline derived table from this table
+ */
+ @Override
+ public TProfile whereNotExists(Select> select) {
+ return where(DSL.notExists(select));
}
}
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfilerole.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfilerole.java
index 4facf8a..d1ecfcf 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfilerole.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/tables/TProfilerole.java
@@ -7,17 +7,26 @@ package de.jottyfan.camporganizer.db.jooq.tables;
import de.jottyfan.camporganizer.db.jooq.Camp;
import de.jottyfan.camporganizer.db.jooq.Keys;
import de.jottyfan.camporganizer.db.jooq.enums.EnumRole;
+import de.jottyfan.camporganizer.db.jooq.tables.TProfile.TProfilePath;
import de.jottyfan.camporganizer.db.jooq.tables.records.TProfileroleRecord;
import java.util.Arrays;
+import java.util.Collection;
import java.util.List;
+import org.jooq.Condition;
import org.jooq.Field;
import org.jooq.ForeignKey;
+import org.jooq.InverseForeignKey;
import org.jooq.Name;
+import org.jooq.Path;
+import org.jooq.PlainSQL;
+import org.jooq.QueryPart;
import org.jooq.Record;
-import org.jooq.Row2;
+import org.jooq.SQL;
import org.jooq.Schema;
+import org.jooq.Select;
+import org.jooq.Stringly;
import org.jooq.Table;
import org.jooq.TableField;
import org.jooq.TableOptions;
@@ -56,14 +65,14 @@ public class TProfilerole extends TableImpl {
/**
* The column camp.t_profilerole.role
.
*/
- public final TableField ROLE = createField(DSL.name("role"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(de.jottyfan.camporganizer.db.jooq.enums.EnumRole.class), this, "");
+ public final TableField ROLE = createField(DSL.name("role"), SQLDataType.VARCHAR.nullable(false).asEnumDataType(EnumRole.class), this, "");
private TProfilerole(Name alias, Table aliased) {
- this(alias, aliased, null);
+ this(alias, aliased, (Field>[]) null, null);
}
- private TProfilerole(Name alias, Table
diff --git a/src/main/java/de/jottyfan/camporganizer/db/jooq/DefaultCatalog.java b/src/main/java/de/jottyfan/camporganizer/db/jooq/DefaultCatalog.java
index 7df6216..253db3c 100644
--- a/src/main/java/de/jottyfan/camporganizer/db/jooq/DefaultCatalog.java
+++ b/src/main/java/de/jottyfan/camporganizer/db/jooq/DefaultCatalog.java
@@ -45,10 +45,10 @@ public class DefaultCatalog extends CatalogImpl {
}
/**
* A reference to the 3.16 minor release of the code generator. If this
* doesn't compile, it's because the runtime library uses an older minor
* release, namely: 3.16. You can turn off the generation of this reference
* by specifying /configuration/generator/generate/jooqVersionReference
*/
- private static final String REQUIRE_RUNTIME_JOOQ_VERSION = Constants.VERSION_3_16;
+ private static final String REQUIRE_RUNTIME_JOOQ_VERSION = Constants.VERSION_3_19;
}
@@ -45,10 +45,10 @@ public class DefaultCatalog extends CatalogImpl {
}
/**
- * A reference to the 3.16 minor release of the code generator. If this
+ * A reference to the 3.19 minor release of the code generator. If this
* doesn't compile, it's because the runtime library uses an older minor
@@ -45,10 +45,10 @@ public class DefaultCatalog extends CatalogImpl {
* doesn't compile, it's because the runtime library uses an older minor
- * release, namely: 3.16. You can turn off the generation of this reference
+ * release, namely: 3.19. You can turn off the generation of this reference
* by specifying /configuration/generator/generate/jooqVersionReference
*/